# jmarkov
jMarkov is a library to simplify the modeling of systems with Markov chains.

With jmarkov it is possible to model
- Continuous-time Markov chains (CTMCs)
- Discrete-time Markov chains (DTMCs)
- Infinite and finite Birth-Death processes (BDs)
- Queueing systems
- Markov decision processes (MDPs)
- Stochastic dynamic programs (SDPs)

To use it you can install it from pypi with the command
```bash
pip install jmarkov
```

You can find the documentation on how to use it [here](https://jmarkov.readthedocs.io/en/latest/)
